@@ -65,6 +65,12 @@ FAILEDOPERATION_CONFIGNAMESPACEQUERYFAILED = 'FailedOperation.ConfigNamespaceQue
 # 配置项查询失败。
 FAILEDOPERATION_CONFIGQUERYFAILED = 'FailedOperation.ConfigQueryFailed'
 
+# 配置项发布日志新增失败。
+FAILEDOPERATION_CONFIGRELEASELOGCREATEFAILED = 'FailedOperation.ConfigReleaseLogCreateFailed'
+
+# 配置项发布日志查询失败。
+FAILEDOPERATION_CONFIGRELEASELOGQUERYFAILED = 'FailedOperation.ConfigReleaseLogQueryFailed'
+
 # 配置项发布信息查询失败。
 FAILEDOPERATION_CONFIGRELEASEQUERYFAILED = 'FailedOperation.ConfigReleaseQueryFailed'
 
@@ -116,12 +122,15 @@ FAILEDOPERATION_DISPATCHCOMMONERROR = 'FailedOperation.DispatchCommonError'
 # 寻找独占配置中心相关指标异常
 FAILEDOPERATION_FINDMETRICSEXCLUSIVEERROR = 'FailedOperation.FindMetricsExclusiveError'
 
-# 网关通用异常:%s。
+# 网关通用异常[网关异常]。
 FAILEDOPERATION_GATEWAYCOMMONERROR = 'FailedOperation.GatewayCommonError'
 
 # 远端访问错误。
 FAILEDOPERATION_GATEWAYREMOTECALLERROR = 'FailedOperation.GatewayRemoteCallError'
 
+# 分组通用错误。
+FAILEDOPERATION_GROUPCOMMONERROR = 'FailedOperation.GroupCommonError'
+
 # 命名空间下存在部署组。
 FAILEDOPERATION_GROUPEXISTS = 'FailedOperation.GroupExists'
 
@@ -173,6 +182,9 @@ FAILEDOPERATION_LANEINFORELEASEMESHFAILED = 'FailedOperation.LaneInfoReleaseMesh
 # 全链路灰度规则启用失败。
 FAILEDOPERATION_LANERULEENABLECONSULFAILED = 'FailedOperation.LaneRuleEnableConsulFailed'
 
+# 该灰度规则生效中,请关闭后删除
+FAILEDOPERATION_LANERULEENABLEDRULEDELETEFAILED = 'FailedOperation.LaneRuleEnabledRuleDeleteFailed'
+
 # 用户全链路灰度规则最大100条。
 FAILEDOPERATION_LANERULEMAXLIMIT = 'FailedOperation.LaneRuleMaxLimit'
 
@@ -236,7 +248,7 @@ FAILEDOPERATION_TASKTERMINATEFAILED = 'FailedOperation.TaskTerminateFailed'
 # 任务更新异常。
 FAILEDOPERATION_TASKUPDATEERROR = 'FailedOperation.TaskUpdateError'
 
-# TKE 集群创建失败，%s。
+# 示例：TKE 集群创建失败，插入数据库失败。
 FAILEDOPERATION_TKECLUSTERCREATEFAILED = 'FailedOperation.TkeClusterCreateFailed'
 
 # TKE 集群删除失败。
@@ -374,7 +386,7 @@ INTERNALERROR_CONTAINERGROUPKUBERNETEDEPLOYMENTNOTFOUND = 'InternalError.Contain
 # 容器应用SQL错误。
 INTERNALERROR_CONTAINERGROUPSQLFAILED = 'InternalError.ContainergroupSqlFailed'
 
-# 容器平台集群不可用，当前状态。有 Idling、Notinit等。
+# 示例：容器平台集群不可用，当前状态 Notinit。
 INTERNALERROR_CPCLUSTERUNAVAILABLE = 'InternalError.CpClusterUnavailable'
 
 # 命令下放失败。
@@ -392,10 +404,10 @@ INTERNALERROR_CVMCAEMASTERQUERYERROR = 'InternalError.CvmCaeMasterQueryError'
 # TSF暂时不能响应请求。
 INTERNALERROR_DISPATCHCOMMONERROR = 'InternalError.DispatchCommonError'
 
-# 网关通用异常:%s。
+# 网关通用异常[网关资源]。
 INTERNALERROR_GATEWAYCOMMONERROR = 'InternalError.GatewayCommonError'
 
-# 数据一致性异常:%s。
+# 数据一致性异常[网关资源]。
 INTERNALERROR_GATEWAYCONSISTENCYERROR = 'InternalError.GatewayConsistencyError'
 
 # 配置中心访问异常。
@@ -437,7 +449,7 @@ INTERNALERROR_SQLTOOMANYINITEM = 'InternalError.SqlTooManyInItem'
 # 任务内部异常。
 INTERNALERROR_TASKINTERNALERROR = 'InternalError.TaskInternalError'
 
-# 调用 TKE 接口失败，%s。
+# 示例：调用 TKE 接口失败，具体报错信息。
 INTERNALERROR_TKEAPIFAILEDOPERATION = 'InternalError.TkeApiFailedOperation'
 
 # TSF应用性能管理业务日志配置与应用关联处理错误。
@@ -635,7 +647,7 @@ INVALIDPARAMETERVALUE_CLUSTERCIDRCONFLICT = 'InvalidParameterValue.ClusterCidrCo
 # 集群命名已存在，请更换其他名称。
 INVALIDPARAMETERVALUE_CLUSTERNAMEEXIST = 'InvalidParameterValue.ClusterNameExist'
 
-# 本环境集群名称禁止以 %s 开头
+# 示例：本环境集群名称禁止以 11 开头
 INVALIDPARAMETERVALUE_CLUSTERNAMEPREFIXILLEGALERROR = 'InvalidParameterValue.ClusterNamePrefixIllegalError'
 
 # 集群命名不能为空。
@@ -686,7 +698,7 @@ INVALIDPARAMETERVALUE_CONFIGTEMPLATETYPEINVALID = 'InvalidParameterValue.ConfigT
 # 配置格式不符合YAML要求。
 INVALIDPARAMETERVALUE_CONFIGVALUEFORMATINVALID = 'InvalidParameterValue.ConfigValueFormatInvalid'
 
-# 配置项值内容大小（%s）超过限制。
+# 配置项值内容大小[当前值]超过限制。
 INVALIDPARAMETERVALUE_CONFIGVALUETOOLONG = 'InvalidParameterValue.ConfigValueTooLong'
 
 # 配置项版本描述不合规。
@@ -824,6 +836,9 @@ INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileCon
 # 文件配置项固定字段不可变更。
 INVALIDPARAMETERVALUE_FILECONFIGFIXEDFIELDUNCHANGEABLE = 'InvalidParameterValue.FileConfigFixedFieldUnchangeable'
 
+# 文件配置项和部署组所属应用不一致。
+INVALIDPARAMETERVALUE_FILECONFIGGROUPAPPLICATIONIDNOTMATCH = 'InvalidParameterValue.FileConfigGroupApplicationIdNotMatch'
+
 # 文件配置项名称不合规。
 INVALIDPARAMETERVALUE_FILECONFIGNAMEINVALID = 'InvalidParameterValue.FileConfigNameInvalid'
 
@@ -842,10 +857,10 @@ INVALIDPARAMETERVALUE_FILECONFIGVERSIONDESCINVALID = 'InvalidParameterValue.File
 # 文件配置项版本不合规。
 INVALIDPARAMETERVALUE_FILECONFIGVERSIONINVALID = 'InvalidParameterValue.FileConfigVersionInvalid'
 
-# 请求参数异常:%s。
+# 请求参数异常[参数]。
 INVALIDPARAMETERVALUE_GATEWAYPARAMETERERROR = 'InvalidParameterValue.GatewayParameterError'
 
-# 无效请求参数:%s。
+# 无效请求参数[参数异常]。
 INVALIDPARAMETERVALUE_GATEWAYPARAMETERINVALID = 'InvalidParameterValue.GatewayParameterInvalid'
 
 # 全局命名空间已经存在，只能创建一个全局命名空间。
@@ -980,6 +995,12 @@ INVALIDPARAMETERVALUE_LANERULETAGVALUETOOLONG = 'InvalidParameterValue.LaneRuleT
 # 全链路灰度规则总标签值不能超过200个字符。
 INVALIDPARAMETERVALUE_LANERULETAGVALUETOTALTOOLONG = 'InvalidParameterValue.LaneRuleTagValueTotalTooLong'
 
+# 无法获取上一次的配置项。
+INVALIDPARAMETERVALUE_LASTCONFIGNOTEXISTS = 'InvalidParameterValue.LastConfigNotExists'
+
+# [参数]不合法。
+INVALIDPARAMETERVALUE_MSPARAMETERINVALID = 'InvalidParameterValue.MsParameterInvalid'
+
 # 集群已关联该命名空间。
 INVALIDPARAMETERVALUE_NAMESPACEALREADYBINDCLUSTER = 'InvalidParameterValue.NamespaceAlreadyBindCluster'
 
@@ -1004,7 +1025,7 @@ INVALIDPARAMETERVALUE_RELEASEDCONFIGCANNOTBEDELETED = 'InvalidParameterValue.Rel
 # 文件配置项已经发布，不允许删除。
 INVALIDPARAMETERVALUE_RELEASEDFILECONFIGCANNOTBEDELETED = 'InvalidParameterValue.ReleasedFileConfigCanNotBeDeleted'
 
-# 无权限操作资源[%s]。
+# 无权限操作资源[资源ID]。
 INVALIDPARAMETERVALUE_RESOURCEPERMISSIONDENIED = 'InvalidParameterValue.ResourcePermissionDenied'
 
 # ResourceType 不支持。
@@ -1082,7 +1103,7 @@ MISSINGPARAMETER_CONFIGVERSIONREQUIRED = 'MissingParameter.ConfigVersionRequired
 # 文件配置项文件内容未填写。
 MISSINGPARAMETER_FILECONFIGFILEVALUEREQUIRED = 'MissingParameter.FileConfigFileValueRequired'
 
-# 缺少请求参数:%s。
+# 缺少请求参数[网关参数异常]。
 MISSINGPARAMETER_GATEWAYPARAMETERREQUIRED = 'MissingParameter.GatewayParameterRequired'
 
 # 分组所属应用不能为空。
@@ -1112,13 +1133,13 @@ MISSINGPARAMETER_NAMESPACEIDREQUIRED = 'MissingParameter.NamespaceIdRequired'
 # 命名空间名称未填写。
 MISSINGPARAMETER_NAMESPACENAMEREQUIRED = 'MissingParameter.NamespaceNameRequired'
 
-# [%s]缺失。
+# [入参]缺失。
 MISSINGPARAMETER_REQUIREDPARAMETERMISSING = 'MissingParameter.RequiredParameterMissing'
 
 # 未填写服务Id。
 MISSINGPARAMETER_SERVICEIDREQUIRED = 'MissingParameter.ServiceIdRequired'
 
-# 未指定%s。
+# 示例：未指定language。
 MISSINGPARAMETER_SYSTEMPARAMETERREQUIRED = 'MissingParameter.SystemParameterRequired'
 
 # 缺少必填参数。
@@ -1127,7 +1148,7 @@ MISSINGPARAMETER_TASKPARAMETERMISSED = 'MissingParameter.TaskParameterMissed'
 # 此应用下存在资源，无法执行删除操作。
 RESOURCEINUSE_APPLICATIONCANNOTDELETE = 'ResourceInUse.ApplicationCannotDelete'
 
-# 资源仍在使用中 无法删除。
+# 资源仍在使用中无法删除。
 RESOURCEINUSE_CVMCAEMASTERCANNOTDELETE = 'ResourceInUse.CvmcaeMasterCannotDelete'
 
 # 默认命名空间不能被删除。
@@ -1229,7 +1250,7 @@ RESOURCENOTFOUND_TASKNOTFOUND = 'ResourceNotFound.TaskNotFound'
 # TKE 中不存在该集群。
 RESOURCENOTFOUND_TKECLUSTERNOTEXISTS = 'ResourceNotFound.TkeClusterNotExists'
 
-# 示例：访问 CAM 系统出错，[报错信息]。
+# 示例：访问 CAM 系统出错，具体报错信息。
 UNAUTHORIZEDOPERATION_CAMGENERALERROR = 'UnauthorizedOperation.CamGeneralError'
 
 # 协作者身份未授权，需要主账号授予协作者权限，参考 TSF 官网文档[子账号获取访问授权](https://cloud.tencent.com/document/product/649/55570)。
@@ -1250,7 +1271,7 @@ UNAUTHORIZEDOPERATION_NOLICENSE = 'UnauthorizedOperation.NoLicense'
 # 用户无权限访问该接口。
 UNAUTHORIZEDOPERATION_NOPRIVILEGE = 'UnauthorizedOperation.NoPrivilege'
 
-# 批量操作数量超过限制:%s。
+# 批量操作数量超过限制[长度]。
 UNSUPPORTEDOPERATION_GATEWAYTOOMANYREQUESTPARAMETER = 'UnsupportedOperation.GatewayTooManyRequestParameter'
 
 # 操作不支持。
